Multivariate Imputation by Chained Equations (MICE) is commonly used to impute missing values in analysis datasets using full conditional specifications. However, it requires that the predictor models are specified correctly, including interactions and nonlinearities. Random Forest is a regression and classification method which can accommodate interactions and non-linearities without requiring a particular statistical model to be specified.
Anoop Shah
Maintainer: anoop@doctors.org.uk
CALIBERrfimpute provides functions that can be used as imputation functions with mice. Note that the mice package itself provides the mice.impute.rf function for imputation using Random Forest, as of version 2.20. The CALIBERrfimpute package provides different, independently developed imputation functions using Random Forest in MICE.
This package contains reports of two simulation studies:
A comparison of Random Forest and parametric MICE in a linear regression example. To open this report, run: utils::browseURL(system.file("doc", "simstudy.pdf", package = "CALIBERrfimpute"))
Compares the Random Forest MICE algorithm (mice.impute.rfcont) with parametric MICE and the algorithms of Doove et al. (mice.impute.cart and mice.impute.rf). To open this report, run: utils::browseURL(system.file("doc", "simstudy_survival_largesample.pdf", package = "CALIBERrfimpute"))
A small sample version of the above simulation as a vignette. See vignette("simstudy_survival", package = "CALIBERrfimpute")
| Package: | CALIBERrfimpute |
| Type: | Package |
| Version: | 1.0-8 |
| Date: | 2026-02-17 |
| License: | GPL-3 |
Shah AD, Bartlett JW, Carpenter J, Nicholas O, Hemingway H. Comparison of Random Forest and parametric imputation models for imputing missing data using MICE: a CALIBER study. American Journal of Epidemiology 2014; 179(6): 764--774. tools:::Rd_expr_doi("10.1093/aje/kwt312")
Doove LL, van Buuren S, Dusseldorp E. Recursive partitioning for missing data imputation in the presence of interaction effects. Computational Statistics and Data Analysis 2014; 72: 92--104. tools:::Rd_expr_doi("10.1016/j.csda.2013.10.025")
mice,
randomForest,
mice.impute.rfcont,
mice.impute.rfcat,
mice.impute.rf